RectangleDetector class

Constructors

RectangleDetector()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

detectAllRectangles(Uint8List imageData) Future<List<RectangleFeature>>
检测图像中的所有矩形并返回矩形特征点列表
detectAllRectanglesFromImage(Image image) Future<List<RectangleFeature>>
从ui.Image检测图像中的所有矩形并返回矩形特征点列表
detectAllRectanglesFromProvider(ImageProvider<Object> imageProvider) Future<List<RectangleFeature>>
从ImageProvider检测图像中的所有矩形并返回矩形特征点列表
detectRectangle(Uint8List imageData) Future<RectangleFeature?>
检测图像中的矩形并返回最大的矩形特征点
detectRectangleFromImage(Image image) Future<RectangleFeature?>
从ui.Image检测图像中的矩形并返回最大的矩形特征点
detectRectangleFromProvider(ImageProvider<Object> imageProvider) Future<RectangleFeature?>
从ImageProvider检测图像中的矩形并返回最大的矩形特征点
getPlatformVersion() Future<String?>