MethodChannelRectangleDetector class

An implementation of RectangleDetectorPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

detectAllRectangles(Uint8List imageData) → Future<List<Map<String, dynamic>>>
检测图片中所有矩形并返回四个顶点坐标
override
detectRectangle(Uint8List imageData) → Future<Map<String, dynamic>?>
检测图片中最大的矩形并返回四个顶点坐标
override
getPlatformVersion() → Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited